@@ -24,34 +24,36 @@
 
 #include "alarmcalendar.h"
 #include "alarmtimewidget.h"
-#include "autoqpointer.h"
-#include "buttongroup.h"
-#include "checkbox.h"
 #include "deferdlg.h"
 #include "functions.h"
 #include "kalarmapp.h"
 #include "latecancel.h"
-#include "lineedit.h"
 #include "mainwindow.h"
-#include "messagebox.h"
-#include "packedlayout.h"
 #include "preferences.h"
-#include "radiobutton.h"
 #include "recurrenceedit.h"
 #include "reminder.h"
-#include "shellprocess.h"
-#include "spinbox.h"
-#include "stackedwidgets.h"
-#include "templatepickdlg.h"
-#include "timeedit.h"
-#include "timespinbox.h"
+#include "resources/datamodel.h"
 #include "resources/resources.h"
+#include "lib/autoqpointer.h"
+#include "lib/buttongroup.h"
+#include "lib/checkbox.h"
+#include "lib/config.h"
+#include "lib/lineedit.h"
+#include "lib/messagebox.h"
+#include "lib/packedlayout.h"
+#include "lib/radiobutton.h"
+#include "lib/shellprocess.h"
+#include "lib/spinbox.h"
+#include "lib/stackedwidgets.h"
+#include "templatepickdlg.h"
+#include "lib/timeedit.h"
+#include "lib/timespinbox.h"
 #include "kalarm_debug.h"
 
 #include <Libkdepim/MaillistDrag>
 
 #include <KLocalizedString>
-#include <kconfig.h>
+#include <KConfig>
 #include <KSharedConfig>
 #include <KWindowSystem>
 
@@ -860,7 +862,7 @@ void EditAlarmDlg::showEvent(QShowEvent* se)
         if (mDeferGroup)
             mDeferGroupHeight = mDeferGroup->height() + style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
         QSize s;
-        if (KAlarm::readConfigWindowSize(mTemplate ? TEMPLATE_DIALOG_NAME : EDIT_DIALOG_NAME, s))
+        if (Config::readWindowSize(mTemplate ? TEMPLATE_DIALOG_NAME : EDIT_DIALOG_NAME, s))
         {
             bool defer = mDeferGroup && !mDeferGroup->isHidden();
             s.setHeight(s.height() + (defer ? mDeferGroupHeight : 0));
@@ -952,7 +954,7 @@ void EditAlarmDlg::resizeEvent(QResizeEvent* re)
     {
         QSize s = re->size();
         s.setHeight(s.height() - (!mDeferGroup || mDeferGroup->isHidden() ? 0 : mDeferGroupHeight));
-        KAlarm::writeConfigWindowSize(mTemplate ? TEMPLATE_DIALOG_NAME : EDIT_DIALOG_NAME, s);
+        Config::writeWindowSize(mTemplate ? TEMPLATE_DIALOG_NAME : EDIT_DIALOG_NAME, s);
     }
     QDialog::resizeEvent(re);
 }
@@ -1160,7 +1162,7 @@ bool EditAlarmDlg::validate()
         bool cancelled = false;
         CalEvent::Type type = mTemplate ? CalEvent::TEMPLATE : CalEvent::ACTIVE;
         if (!mResource.isWritable(type))
-            mResource = Resources::destination<AkonadiModel>(type, this, false, &cancelled);
+            mResource = Resources::destination(type, this, false, &cancelled);
         if (!mResource.isValid())
         {
             if (!cancelled)
