@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Laurent Montel <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   based on code from Sune Vuorela <sune@vuorela.dk> (Rawatar source code)
 
@@ -20,7 +20,7 @@
 #ifndef KALARMMIGRATEAPPLICATION_H
 #define KALARMMIGRATEAPPLICATION_H
 
-#include <pimcommon/migrateapplicationfiles.h>
+#include <PimCommon/MigrateApplicationFiles>
 
 class KAlarmMigrateApplication
 {
