@@ -21,11 +21,11 @@
 #include "lineedit.h"
 
 #include <Libkdepim/MaillistDrag>
-#include <kcontacts/vcarddrag.h>
-#include <KCalUtils/kcalutils/icaldrag.h>
+#include <KContacts/VCardDrag>
+#include <KCalUtils/ICalDrag>
 
-#include <kurlcompletion.h>
-#include <kshell.h>
+#include <KUrlCompletion>
+#include <KShell>
 
 #include <QUrl>
 #include <QRegExp>
@@ -177,7 +177,11 @@ void LineEdit::dropEvent(QDropEvent* e)
         {
             // Remove newlines from a list of email addresses, and allow an eventual mailto: scheme
             const QString mailto = QStringLiteral("mailto:");
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             newEmails = txt.split(QRegExp(QLatin1String("[\r\n]+")), QString::SkipEmptyParts);
+#else
+            newEmails = txt.split(QRegExp(QLatin1String("[\r\n]+")), Qt::SkipEmptyParts);
+#endif
             for (QStringList::Iterator it = newEmails.begin();  it != newEmails.end();  ++it)
             {
                 if ((*it).startsWith(mailto))
