@@ -22,53 +22,55 @@
 
 #include "alarmcalendar.h"
 #include "alarmlistdelegate.h"
-#include "autoqpointer.h"
 #include "alarmlistview.h"
 #include "birthdaydlg.h"
 #include "functions.h"
 #include "kalarmapp.h"
 #include "kamail.h"
-#include "messagebox.h"
 #include "newalarmaction.h"
 #include "prefdlg.h"
 #include "preferences.h"
 #include "resourceselector.h"
-#include "synchtimer.h"
 #include "templatedlg.h"
 #include "templatemenuaction.h"
 #include "templatepickdlg.h"
 #include "traywindow.h"
 #include "wakedlg.h"
+#include "resources/datamodel.h"
 #include "resources/resources.h"
 #include "resources/eventmodel.h"
+#include "lib/autoqpointer.h"
+#include "lib/messagebox.h"
+#include "lib/synchtimer.h"
 #include "kalarm_debug.h"
 
-#include <kalarmcal/alarmtext.h>
-#include <kalarmcal/kaevent.h>
+#include <KAlarmCal/AlarmText>
+#include <KAlarmCal/KAEvent>
 
 #include <Libkdepim/MaillistDrag>
-#include <kmime/kmime_message.h>
-#include <AkonadiCore/item.h>
-#include <AkonadiCore/itemfetchjob.h>
-#include <AkonadiCore/itemfetchscope.h>
-#include <AkonadiWidgets/controlgui.h>
+#include <KMime/Message>
+#include <AkonadiCore/Item>
+#include <AkonadiCore/ItemFetchJob>
+#include <AkonadiCore/ItemFetchScope>
+#include <AkonadiWidgets/ControlGui>
 #include <KCalendarCore/MemoryCalendar>
-#include <KCalUtils/kcalutils/icaldrag.h>
+#include <KCalUtils/ICalDrag>
 using namespace KCalendarCore;
 using namespace KCalUtils;
+
 #include <KAboutData>
-#include <ktoolbar.h>
+#include <KToolBar>
 #include <KActionCollection>
 #include <KGlobalAccel>
-#include <kstandardaction.h>
+#include <KStandardAction>
 #include <KLocalizedString>
 #include <KSharedConfig>
-#include <kconfiggroup.h>
-#include <kshortcutsdialog.h>
-#include <kedittoolbar.h>
-#include <kxmlguifactory.h>
-#include <ktoggleaction.h>
-#include <ktoolbarpopupaction.h>
+#include <KConfigGroup>
+#include <KShortcutsDialog>
+#include <KEditToolBar>
+#include <KXMLGUIFactory>
+#include <KToggleAction>
+#include <KToolBarPopupAction>
 
 #include <QAction>
 #include <QLocale>
@@ -159,7 +161,7 @@ MainWindow::MainWindow(bool restored)
     mSplitter->setStretchFactor(1, 1);
 
     // Create the alarm list widget
-    mListFilterModel = AlarmListModel::create<AkonadiModel>(this);
+    mListFilterModel = DataModel::createAlarmListModel(this);
     mListFilterModel->setEventTypeFilter(mShowArchived ? CalEvent::ACTIVE | CalEvent::ARCHIVED : CalEvent::ACTIVE);
     mListView = new AlarmListView(WINDOW_NAME, mSplitter);
     mListView->setModel(mListFilterModel);
@@ -621,7 +623,7 @@ void MainWindow::enableTemplateMenuItem(bool enable)
 void MainWindow::refresh()
 {
     qCDebug(KALARM_LOG) << "MainWindow::refresh";
-    AkonadiModel::instance()->reload();
+    DataModel::reload();
 }
 
 /******************************************************************************
