@@ -1,7 +1,7 @@
 /*
  *  messagewin.cpp  -  displays an alarm message
  *  Program:  kalarm
- *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,45 +21,46 @@
 #include "messagewin.h"
 #include "messagewin_p.h"
 #include "config-kalarm.h"
+#include <kio_version.h>
 
 #include "alarmcalendar.h"
-#include "autoqpointer.h"
 #include "deferdlg.h"
-#include "desktop.h"
 #include "editdlg.h"
 #include "functions.h"
 #include "kalarmapp.h"
 #include "mainwindow.h"
-#include "messagebox.h"
 #include "preferences.h"
-#include "pushbutton.h"
-#include "shellprocess.h"
-#include "synchtimer.h"
 #include "resources/resources.h"
+#include "lib/autoqpointer.h"
+#include "lib/config.h"
+#include "lib/desktop.h"
+#include "lib/file.h"
+#include "lib/messagebox.h"
+#include "lib/pushbutton.h"
+#include "lib/shellprocess.h"
+#include "lib/synchtimer.h"
 #include "kalarm_debug.h"
 
-#include <kpimtextedit/texttospeech.h>
-#include <AkonadiCore/itemfetchjob.h>
-#include <AkonadiCore/itemfetchscope.h>
+#include <KPIMTextEdit/TextToSpeech>
+#include <AkonadiCore/ItemFetchJob>
+#include <AkonadiCore/ItemFetchScope>
 
-#include <kwindowsystem_version.h>
 #include <KAboutData>
-#include <kstandardguiitem.h>
+#include <KStandardGuiItem>
 #include <KLocalizedString>
-#include <kconfig.h>
-#include <kiconloader.h>
-#include <ktextedit.h>
-#include <kwindowsystem.h>
+#include <KConfig>
+#include <KTextEdit>
+#include <KWindowSystem>
 #include <KIO/StatJob>
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
-#include <knotification.h>
-#include <ksqueezedtextlabel.h>
+#include <KNotification>
+#include <KSqueezedTextLabel>
 #include <phonon/mediaobject.h>
 #include <phonon/audiooutput.h>
 #include <phonon/volumefadereffect.h>
 #if KDEPIM_HAVE_X11
-#include <kwindowinfo.h>
+#include <KWindowInfo>
 #include <netwm.h>
 #include <qx11info_x11.h>
 #include <QScreen>
@@ -397,7 +398,11 @@ void MessageWin::initView()
                 // Display contents of file
                 const QUrl url = QUrl::fromUserInput(mMessage, QString(), QUrl::AssumeLocalFile);
 
-                auto statJob =  KIO::stat(url, KIO::StatJob::SourceSide, 0, KIO::HideProgressInfo);
+#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
+                auto statJob = KIO::stat(url, KIO::StatJob::SourceSide, 0, KIO::HideProgressInfo);
+#else
+                auto statJob = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatDetail::Basic, KIO::HideProgressInfo);
+#endif
                 const bool exists = statJob->exec();
                 const bool isDir = statJob->statResult().isDir();
 
@@ -415,11 +420,11 @@ void MessageWin::initView()
                         QMimeType mime = db.mimeTypeForUrl(url);
                         if (mime.name() == QLatin1String("application/octet-stream"))
                             mime = db.mimeTypeForData(mTempFile);
-                        const KAlarm::FileType fileType = KAlarm::fileType(mime);
+                        const File::FileType fileType = File::fileType(mime);
                         switch (fileType)
                         {
-                            case KAlarm::Image:
-                            case KAlarm::TextFormatted:
+                            case File::Image:
+                            case File::TextFormatted:
                                 delete mTempFile;
                                 mTempFile = new QTemporaryFile;
                                 mTempFile->open();
@@ -440,11 +445,11 @@ void MessageWin::initView()
 
                         switch (fileType)
                         {
-                            case KAlarm::Image:
+                            case File::Image:
                                 view->setHtml(QLatin1String("<div align=\"center\"><img src=\"") + mTempFile->fileName() + QLatin1String("\"></div>"));
                                 mTempFile->close();   // keep the file available to be displayed
                                 break;
-                            case KAlarm::TextFormatted:
+                            case File::TextFormatted:
                                 view->QTextBrowser::setSource(QUrl::fromLocalFile(mTempFile->fileName()));   //krazy:exclude=qclasses
                                 delete mTempFile;
                                 mTempFile = nullptr;
@@ -494,7 +499,7 @@ void MessageWin::initView()
                 topLayout->addSpacing(vspace);
                 topLayout->addStretch();
                 // Don't include any horizontal margins if message is 2/3 screen width
-                if (text->sizeHint().width() >= KAlarm::desktopWorkArea(mScreenNumber).width()*2/3)
+                if (text->sizeHint().width() >= Desktop::workArea(mScreenNumber).width()*2/3)
                     topLayout->addWidget(text, 1, Qt::AlignHCenter);
                 else
                 {
@@ -603,7 +608,7 @@ void MessageWin::initView()
         layout->addStretch();
         topLayout->addLayout(layout);
         QLabel* label = new QLabel(topWidget);
-        label->setPixmap(QIcon::fromTheme(QStringLiteral("dialog-error")).pixmap(IconSize(KIconLoader::Desktop), IconSize(KIconLoader::Desktop)));
+        label->setPixmap(QIcon::fromTheme(QStringLiteral("dialog-error")).pixmap(style()->pixelMetric(QStyle::PM_MessageBoxIconSize)));
         label->setFixedSize(label->sizeHint());
         layout->addWidget(label, 0, Qt::AlignRight);
         QVBoxLayout* vlayout = new QVBoxLayout();
@@ -663,13 +668,11 @@ void MessageWin::initView()
     else
         setDeferralLimit(mEvent);    // ensure that button is disabled when alarm can't be deferred any more
 
-    KIconLoader iconLoader;
     if (!mAudioFile.isEmpty()  &&  (mVolume || mFadeVolume > 0))
     {
         // Silence button to stop sound repetition
-        const QPixmap pixmap = iconLoader.loadIcon(QStringLiteral("media-playback-stop"), KIconLoader::MainToolbar);
         mSilenceButton = new PushButton(topWidget);
-        mSilenceButton->setIcon(pixmap);
+        mSilenceButton->setIcon(QIcon::fromTheme(QStringLiteral("media-playback-stop")));
         grid->addWidget(mSilenceButton, 0, gridIndex++, Qt::AlignHCenter);
         mSilenceButton->setToolTip(i18nc("@info:tooltip", "Stop sound"));
         mSilenceButton->setWhatsThis(i18nc("@info:whatsthis", "Stop playing the sound"));
@@ -680,9 +683,8 @@ void MessageWin::initView()
     if (mAkonadiItemId >= 0)
     {
         // KMail button
-        const QPixmap pixmap = iconLoader.loadIcon(QStringLiteral("internet-mail"), KIconLoader::MainToolbar);
         mKMailButton = new PushButton(topWidget);
-        mKMailButton->setIcon(pixmap);
+        mKMailButton->setIcon(QIcon::fromTheme(QStringLiteral("internet-mail")));
         connect(mKMailButton, &QAbstractButton::clicked, this, &MessageWin::slotShowKMailMessage);
         grid->addWidget(mKMailButton, 0, gridIndex++, Qt::AlignHCenter);
         mKMailButton->setToolTip(xi18nc("@info:tooltip Locate this email in KMail", "Locate in <application>KMail</application>"));
@@ -690,9 +692,8 @@ void MessageWin::initView()
     }
 
     // KAlarm button
-    const QPixmap pixmap = iconLoader.loadIcon(KAboutData::applicationData().componentName(), KIconLoader::MainToolbar);
     mKAlarmButton = new PushButton(topWidget);
-    mKAlarmButton->setIcon(pixmap);
+    mKAlarmButton->setIcon(QIcon::fromTheme(KAboutData::applicationData().componentName()));
     connect(mKAlarmButton, &QAbstractButton::clicked, this, &MessageWin::displayMainWindow);
     grid->addWidget(mKAlarmButton, 0, gridIndex++, Qt::AlignHCenter);
     mKAlarmButton->setToolTip(xi18nc("@info:tooltip", "Activate <application>KAlarm</application>"));
@@ -932,12 +933,19 @@ void MessageWin::saveProperties(KConfigGroup& config)
         config.writeEntry("ConfirmAck", mConfirmAck);
         if (mDateTime.isValid())
         {
-//TODO: Write KADateTime when it becomes possible
             config.writeEntry("Time", mDateTime.effectiveDateTime());
             config.writeEntry("DateOnly", mDateTime.isDateOnly());
             QByteArray zone;
             if (mDateTime.isUtc())
                 zone = "UTC";
+            else if (mDateTime.isOffsetFromUtc())
+            {
+                int offset = mDateTime.utcOffset();
+                if (offset >= 0)
+                    zone = '+' + QByteArray::number(offset);
+                else
+                    zone = QByteArray::number(offset);
+            }
             else if (mDateTime.timeType() == KADateTime::TimeZone)
             {
                 const QTimeZone tz = mDateTime.timeZone();
@@ -998,6 +1006,8 @@ void MessageWin::readProperties(const KConfigGroup& config)
         timeSpec = KADateTime::LocalZone;
     else if (zoneId == "UTC")
         timeSpec = KADateTime::UTC;
+    else if (zoneId.startsWith('+')  ||  zoneId.startsWith('-'))
+        timeSpec.setType(KADateTime::OffsetFromUTC, zoneId.toInt());
     else
         timeSpec = QTimeZone(zoneId);
     mDateTime = KADateTime(dt.date(), dt.time(), timeSpec);
@@ -1061,7 +1071,7 @@ void MessageWin::showRestoredAlarm()
 void MessageWin::redisplayAlarm()
 {
     mResource = Resources::resourceForEvent(mEventId.eventId());
-    mEventId.setCollectionId(mResource.id());
+    mEventId.setResourceId(mResource.id());
     qCDebug(KALARM_LOG) << "MessageWin::redisplayAlarm:" << mEventId;
     // Delete any already existing window for the same event
     MessageWin* duplicate = findEvent(mEventId, this);
@@ -1172,10 +1182,10 @@ bool MessageWin::reinstateFromDisplaying(const Event::Ptr& kcalEvent, KAEvent& e
 {
     if (!kcalEvent)
         return false;
-    Akonadi::Collection::Id collectionId;
-    event.reinstateFromDisplaying(kcalEvent, collectionId, showEdit, showDefer);
-    event.setCollectionId(collectionId);
-    resource = Resources::resource(collectionId);
+    ResourceId resourceId;
+    event.reinstateFromDisplaying(kcalEvent, resourceId, showEdit, showDefer);
+    event.setCollectionId(resourceId);
+    resource = Resources::resource(resourceId);
     qCDebug(KALARM_LOG) << "MessageWin::reinstateFromDisplaying:" << EventId(event) << ": success";
     return true;
 }
@@ -1222,7 +1232,7 @@ bool MessageWin::spread(bool scatter)
     if (instanceCount(true) <= 1)    // ignore always-hidden windows
         return false;
 
-    const QRect desk = KAlarm::desktopWorkArea();   // get the usable area of the desktop
+    const QRect desk = Desktop::workArea();   // get the usable area of the desktop
     if (scatter == isSpread(desk.topLeft()))
         return scatter;
 
@@ -1725,7 +1735,7 @@ QSize MessageWin::sizeHint() const
     }
 
     // Limit the size to fit inside the working area of the desktop
-    const QSize desktop = KAlarm::desktopWorkArea(mScreenNumber).size();
+    const QSize desktop = Desktop::workArea(mScreenNumber).size();
     const QSize frameThickness = frameGeometry().size() - geometry().size();  // title bar & window frame
     return desired.boundedTo(desktop - frameThickness);
 }
@@ -1756,10 +1766,10 @@ void MessageWin::showEvent(QShowEvent* se)
         bool execComplete = true;
         QSize s = sizeHint();     // fit the window round the message
         if (mAction == KAEvent::FILE  &&  !mErrorMsgs.count())
-            KAlarm::readConfigWindowSize("FileMessage", s);
+            Config::readWindowSize("FileMessage", s);
         resize(s);
 
-        const QRect desk = KAlarm::desktopWorkArea(mScreenNumber);
+        const QRect desk = Desktop::workArea(mScreenNumber);
         const QRect frame = frameGeometry();
 
         mButtonDelay = Preferences::messageButtonDelay() * 1000;
@@ -1832,7 +1842,7 @@ void MessageWin::showEvent(QShowEvent* se)
 void MessageWin::moveEvent(QMoveEvent* e)
 {
     MainWindowBase::moveEvent(e);
-    theApp()->setSpreadWindowsState(isSpread(KAlarm::desktopWorkArea(mScreenNumber).topLeft()));
+    theApp()->setSpreadWindowsState(isSpread(Desktop::workArea(mScreenNumber).topLeft()));
     if (mPositioning)
     {
         // The window has just been initially positioned
@@ -1854,7 +1864,7 @@ void MessageWin::frameDrawn()
         if (width() > s.width()  ||  height() > s.height())
             resize(s);
     }
-    theApp()->setSpreadWindowsState(isSpread(KAlarm::desktopWorkArea(mScreenNumber).topLeft()));
+    theApp()->setSpreadWindowsState(isSpread(Desktop::workArea(mScreenNumber).topLeft()));
 }
 
 /******************************************************************************
@@ -1914,7 +1924,7 @@ void MessageWin::resizeEvent(QResizeEvent* re)
     else
     {
         if (mShown  &&  mAction == KAEvent::FILE  &&  !mErrorMsgs.count())
-            KAlarm::writeConfigWindowSize("FileMessage", re->size());
+            Config::writeWindowSize("FileMessage", re->size());
         MainWindowBase::resizeEvent(re);
     }
 }
@@ -2021,12 +2031,8 @@ void MessageWin::slotEdit()
     qCDebug(KALARM_LOG) << "MessageWin::slotEdit";
     MainWindow* mainWin = MainWindow::mainMainWindow();
     mEditDlg = EditAlarmDlg::create(false, &mOriginalEvent, false, mainWin, EditAlarmDlg::RES_IGNORE);
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5,62,0)
     mEditDlg->setAttribute(Qt::WA_NativeWindow, true);
     KWindowSystem::setMainWindow(mEditDlg->windowHandle(), winId());
-#else
-    KWindowSystem::setMainWindow(mEditDlg, winId());
-#endif
     KWindowSystem::setOnAllDesktops(mEditDlg->winId(), false);
     setButtonsReadOnly(true);
     connect(mEditDlg, &QDialog::accepted, this, &MessageWin::editCloseOk);
