@@ -1,7 +1,7 @@
 /*
  *  akonadiresource.cpp  -  class for an Akonadi alarm calendar resource
  *  Program:  kalarm
- *  Copyright © 2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2019-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,14 +21,15 @@
 #include "akonadiresource.h"
 
 #include "resources.h"
-#include "akonadimodel.h"
-#include "autoqpointer.h"
-#include "calendarmigrator.h"
-#include "kalarm_debug.h"
+#include "akonadicalendarupdater.h"
+#include "akonadidatamodel.h"
+#include "akonadiresourcemigrator.h"
+#include "lib/autoqpointer.h"
 
-#include <kalarmcal/akonadi.h>
-#include <kalarmcal/compatibilityattribute.h>
-#include <kalarmcal/eventattribute.h>
+#include <KAlarmCal/Akonadi>
+#include <KAlarmCal/CompatibilityAttribute>
+#include <KAlarmCal/EventAttribute>
+#include <KAlarmCal/Version>
 
 #include <AkonadiCore/AgentManager>
 #include <AkonadiCore/ChangeRecorder>
@@ -46,15 +47,15 @@ using namespace Akonadi;
 
 namespace
 {
-const QString KALARM_RESOURCE(QStringLiteral("akonadi_kalarm_resource"));
-const QString KALARM_DIR_RESOURCE(QStringLiteral("akonadi_kalarm_dir_resource"));
-
 const Collection::Rights WritableRights = Collection::CanChangeItem | Collection::CanCreateItem | Collection::CanDeleteItem;
 
 const QRegularExpression MatchMimeType(QStringLiteral("^application/x-vnd\\.kde\\.alarm.*"),
                                        QRegularExpression::DotMatchesEverythingOption);
 }
 
+const QString AkonadiResource::KALARM_RESOURCE(QStringLiteral("akonadi_kalarm_resource"));
+const QString AkonadiResource::KALARM_DIR_RESOURCE(QStringLiteral("akonadi_kalarm_dir_resource"));
+
 // Class to provide an object for removeDuplicateResources() signals to be received.
 class DuplicateResourceObject : public QObject
 {
@@ -75,7 +76,7 @@ private:
     };
     QHash<QString, ResourceCol> mAgentPaths;   // path, (resource identifier, collection ID) pairs
 };
-DuplicateResourceObject* AkonadiResource::mDuplicateResourceObject{nullptr};
+DuplicateResourceObject* AkonadiResource::mDuplicateResourceObject {nullptr};
 
 
 Resource AkonadiResource::create(const Akonadi::Collection& collection)
@@ -104,7 +105,7 @@ AkonadiResource::AkonadiResource(const Collection& collection)
         // If the collection doesn't belong to a resource, it can't be used.
         mValid = AgentManager::self()->instance(mCollection.resource()).isValid();
 
-        connect(AkonadiModel::monitor(), &Monitor::collectionRemoved, this, &AkonadiResource::slotCollectionRemoved);
+        connect(AkonadiDataModel::monitor(), &Monitor::collectionRemoved, this, &AkonadiResource::slotCollectionRemoved);
     }
 }
 
@@ -221,7 +222,7 @@ void AkonadiResource::setEnabled(CalEvent::Types types)
 
 bool AkonadiResource::readOnly() const
 {
-    AkonadiModel::instance()->refresh(mCollection);    // update with latest data
+    AkonadiDataModel::instance()->refresh(mCollection);    // update with latest data
     return (mCollection.rights() & WritableRights) != WritableRights;
 }
 
@@ -229,7 +230,7 @@ int AkonadiResource::writableStatus(CalEvent::Type type) const
 {
     if (!mValid)
         return -1;
-    AkonadiModel::instance()->refresh(mCollection);    // update with latest data
+    AkonadiDataModel::instance()->refresh(mCollection);    // update with latest data
     if ((type == CalEvent::EMPTY  && !enabledTypes())
     ||  (type != CalEvent::EMPTY  && !isEnabled(type)))
         return -1;
@@ -329,14 +330,17 @@ void AkonadiResource::configSetStandard(CalEvent::Types types)
     modifyCollectionAttribute();
 }
 
-KACalendar::Compat AkonadiResource::compatibility() const
+KACalendar::Compat AkonadiResource::compatibilityVersion(QString& versionString) const
 {
+    versionString.clear();
     if (!mValid)
         return KACalendar::Incompatible;
-    AkonadiModel::instance()->refresh(mCollection);    // update with latest data
+    AkonadiDataModel::instance()->refresh(mCollection);    // update with latest data
     if (!mCollection.hasAttribute<CompatibilityAttribute>())
         return KACalendar::Incompatible;
-    return mCollection.attribute<CompatibilityAttribute>()->compatibility();
+    const CompatibilityAttribute* attr = mCollection.attribute<CompatibilityAttribute>();
+    versionString = KAlarmCal::getVersionString(attr->version());
+    return attr->compatibility();
 }
 
 /******************************************************************************
@@ -367,7 +371,7 @@ bool AkonadiResource::removeResource()
 {
     if (!isValid())
         return false;
-    qCDebug(KALARM_LOG) << "AkonadiResource::removeResource:" << id();
+    qCDebug(KALARM_LOG) << "AkonadiResource::removeResource:" << displayId();
     notifyDeletion();
     // Note: Don't use CollectionDeleteJob, since that also deletes the backend storage.
     AgentManager* agentManager = AgentManager::self();
@@ -386,8 +390,8 @@ void AkonadiResource::slotCollectionRemoved(const Collection& collection)
 {
     if (collection.id() == id())
     {
-        qCDebug(KALARM_LOG) << "AkonadiResource::slotCollectionRemoved:" << id();
-        disconnect(AkonadiModel::monitor(), nullptr, this, nullptr);
+        qCDebug(KALARM_LOG) << "AkonadiResource::slotCollectionRemoved:" << displayId();
+        disconnect(AkonadiDataModel::monitor(), nullptr, this, nullptr);
         ResourceType::removeResource(collection.id());
     }
 }
@@ -403,25 +407,27 @@ bool AkonadiResource::isPopulated() const
 {
     if (!ResourceType::isPopulated())
     {
-        const QModelIndex ix = AkonadiModel::instance()->resourceIndex(mCollection.id());
-        if (!ix.data(AkonadiModel::IsPopulatedRole).toBool())
+        const QModelIndex ix = AkonadiDataModel::instance()->resourceIndex(mCollection.id());
+        if (!ix.data(AkonadiDataModel::IsPopulatedRole).toBool())
             return false;
         setLoaded(true);
     }
     return true;
 }
 
-bool AkonadiResource::save(bool writeThroughCache)
+bool AkonadiResource::save(bool writeThroughCache, bool force)
 {
     Q_UNUSED(writeThroughCache);
+    Q_UNUSED(force);
     AgentManager::self()->instance(mCollection.resource()).synchronize();
     return true;
 }
 
-#if 0
-        /** Reload the resource. Any cached data is first discarded. */
-        bool reload() override;
-#endif
+bool AkonadiResource::reload()
+{
+    // Akonadi provides no means to reload from the backend.
+    return false;
+}
 
 /******************************************************************************
 * Add an event to the resource, and add it to Akonadi.
@@ -449,7 +455,7 @@ bool AkonadiResource::addEvent(const KAEvent& event)
 bool AkonadiResource::updateEvent(const KAEvent& event)
 {
     qCDebug(KALARM_LOG) << "AkonadiResource::updateEvent:" << event.id();
-    Item item = AkonadiModel::instance()->itemForEvent(event.id());
+    Item item = AkonadiDataModel::instance()->itemForEvent(event.id());
     if (!item.isValid())
         return false;
     if (!KAlarmCal::setItemPayload(item, event, mCollection.contentMimeTypes()))
@@ -472,7 +478,7 @@ bool AkonadiResource::deleteEvent(const KAEvent& event)
         qCDebug(KALARM_LOG) << "AkonadiResource::deleteEvent: Collection being deleted";
         return true;    // the event's collection is being deleted
     }
-    const Item item = AkonadiModel::instance()->itemForEvent(event.id());
+    const Item item = AkonadiDataModel::instance()->itemForEvent(event.id());
     if (!item.isValid())
         return false;
     ItemDeleteJob* job = new ItemDeleteJob(item);
@@ -487,7 +493,7 @@ bool AkonadiResource::deleteEvent(const KAEvent& event)
 */
 void AkonadiResource::handleCommandErrorChange(const KAEvent& event)
 {
-    Item item = AkonadiModel::instance()->itemForEvent(event.id());
+    Item item = AkonadiDataModel::instance()->itemForEvent(event.id());
     if (item.isValid())
     {
         const KAEvent::CmdErrType err = event.commandError();
@@ -549,16 +555,6 @@ KAEvent AkonadiResource::event(Resource& resource, const Akonadi::Item& item)
     return ev;
 }
 
-/******************************************************************************
-* Get the collection to use for storing an alarm.
-* Optionally, the standard collection for the alarm type is returned. If more
-* than one collection is a candidate, the user is prompted.
-*/
-Resource AkonadiResource::destination(CalEvent::Type type, QWidget* promptParent, bool noPrompt, bool* cancelled)
-{
-    return Resources::destination<AkonadiModel>(type, promptParent, noPrompt, cancelled);
-}
-
 /******************************************************************************
 * Check for, and remove, any Akonadi resources which duplicate use of calendar
 * files/directories.
@@ -705,14 +701,10 @@ void AkonadiResource::notifyCollectionChanged(Resource& res, const Collection& c
         ||  *collection.attribute<CompatibilityAttribute>() != *akres->mCollection.attribute<CompatibilityAttribute>())
         {
             // Update to current KAlarm format if necessary, and if the user agrees.
-            // Create a new temporary 'Resource' object, because the one passed
-            // to this method can get overwritten with an old version of its
-            // CompatibilityAttribute before CalendarMigration finishes, due to
-            // AkonadiModel still containing an out of date value.
             qCDebug(KALARM_LOG) << "AkonadiResource::setCollectionChanged:" << collection.id() << ": compatibility ->" << collection.attribute<CompatibilityAttribute>()->compatibility();
             // Note that the AkonadiResource will be deleted once no more
             // QSharedPointers reference it.
-            CalendarMigrator::updateToCurrentFormat(res, false);
+            AkonadiCalendarUpdater::updateToCurrentFormat(res, false, akres);
         }
     }
 }
@@ -781,7 +773,7 @@ void AkonadiResource::queueItemModifyJob(const Item& item)
         {
             Item newItem = item;
             Item current = item;
-            if (AkonadiModel::instance()->refresh(current))  // fetch the up-to-date item
+            if (AkonadiDataModel::instance()->refresh(current))  // fetch the up-to-date item
                 newItem.setRevision(current.revision());
             mItemModifyJobQueue[item.id()] = Item();   // mark the queued item as now executing
             ItemModifyJob* job = new ItemModifyJob(newItem);
@@ -828,7 +820,7 @@ void AkonadiResource::itemJobDone(KJob* j)
         if (itemId >= 0  &&  jobClass == "Akonadi::ItemModifyJob")
         {
             // Execute the next queued job for this item
-            const Item current = AkonadiModel::instance()->itemById(itemId);  // fetch the up-to-date item
+            const Item current = AkonadiDataModel::instance()->itemById(itemId);  // fetch the up-to-date item
             checkQueuedItemModifyJob(current);
         }
         Resources::notifyResourceMessage(this, MessageType::Error, errMsg, j->errorString());
@@ -901,7 +893,7 @@ void AkonadiResource::checkQueuedItemModifyJob(const Item& item)
 void AkonadiResource::fetchCollectionAttribute(bool refresh) const
 {
     if (refresh)
-        AkonadiModel::instance()->refresh(mCollection);    // update with latest data
+        AkonadiDataModel::instance()->refresh(mCollection);    // update with latest data
     if (!mCollection.hasAttribute<CollectionAttribute>())
     {
         mCollectionAttribute = CollectionAttribute();
@@ -944,7 +936,7 @@ void AkonadiResource::modifyCollectionAttrJobDone(KJob* j)
     {
         // If the collection is being/has been deleted, ignore the error.
         if (!isBeingDeleted()
-        &&  AkonadiModel::instance()->resource(id).isValid()
+        &&  AkonadiDataModel::instance()->resource(id).isValid()
         &&  id == mCollection.id())
         {
             qCCritical(KALARM_LOG) << "AkonadiResource::modifyCollectionAttrJobDone:" << collection.id() << "Failed to update calendar" << displayName() << ":" << j->errorString();
@@ -953,7 +945,7 @@ void AkonadiResource::modifyCollectionAttrJobDone(KJob* j)
     }
     else
     {
-        AkonadiModel::instance()->refresh(mCollection);   // pick up the modified attribute
+        AkonadiDataModel::instance()->refresh(mCollection);   // pick up the modified attribute
         if (newEnabled)
         {
             const CalEvent::Types oldEnabled = mLastEnabled;
