@@ -1,7 +1,7 @@
 /*
  *  resourcemodel.cpp  -  models containing flat list of resources
  *  Program:  kalarm
- *  Copyright © 2007-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2007-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,8 +22,8 @@
 
 #include "resourcedatamodelbase.h"
 #include "resources.h"
-#include "messagebox.h"
 #include "preferences.h"
+#include "lib/messagebox.h"
 #include "kalarm_debug.h"
 
 #include <KLocalizedString>
@@ -131,15 +131,11 @@ bool ResourceFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex& sou
         return false;   // invalidly configured resource
     if (!mWritableOnly  &&  mAlarmType == CalEvent::EMPTY)
         return true;
-    if (mWritableOnly  &&  !resource.isWritable())
-        return false;
-    if (mAlarmType != CalEvent::EMPTY  &&  !(resource.alarmTypes() & mAlarmType))
-        return false;
-    if (mWritableOnly  &&  !resource.isCompatible())
-        return false;
-    if (mEnabledOnly  &&  !resource.isEnabled(mAlarmType))
-        return false;
-    if (!mFilterText.isEmpty()  &&  !resource.displayName().contains(mFilterText, Qt::CaseInsensitive))
+    if ((mWritableOnly  &&  !resource.isWritable())
+    ||  (mAlarmType != CalEvent::EMPTY  &&  !(resource.alarmTypes() & mAlarmType))
+    ||  (mWritableOnly  &&  !resource.isCompatible())
+    ||  (mEnabledOnly  &&  !resource.isEnabled(mAlarmType))
+    ||  (!mFilterText.isEmpty()  &&  !resource.displayName().contains(mFilterText, Qt::CaseInsensitive)))
         return false;
     return true;
 }
@@ -421,9 +417,9 @@ void ResourceCheckListModel::resourceSettingsChanged(Resource& res, ResourceType
         return;
 
     if (change & ResourceType::Enabled)
-        qCDebug(KALARM_LOG) << debugType("resourceSettingsChanged").constData() << res.id() << "Enabled" << res.enabledTypes();
+        qCDebug(KALARM_LOG) << debugType("resourceSettingsChanged").constData() << res.displayId() << "Enabled" << res.enabledTypes();
     if (change & ResourceType::AlarmTypes)
-        qCDebug(KALARM_LOG) << debugType("resourceSettingsChanged").constData() << res.id() << "AlarmTypes" << res.alarmTypes();
+        qCDebug(KALARM_LOG) << debugType("resourceSettingsChanged").constData() << res.displayId() << "AlarmTypes" << res.alarmTypes();
 
     const QModelIndex ix = mModel->resourceIndex(res);
     if (ix.isValid())
@@ -486,10 +482,13 @@ void ResourceFilterCheckListModel::setEventTypeFilter(CalEvent::Type type)
 {
     if (type != mAlarmType)
     {
-        disconnect(sourceModel(), &QAbstractItemModel::rowsAboutToBeInserted, this, nullptr);
-        disconnect(sourceModel(), &QAbstractItemModel::rowsAboutToBeRemoved, this, nullptr);
-        disconnect(sourceModel(), &QAbstractItemModel::rowsInserted, this, nullptr);
-        disconnect(sourceModel(), &QAbstractItemModel::rowsRemoved, this, nullptr);
+        if (sourceModel())
+        {
+            disconnect(sourceModel(), &QAbstractItemModel::rowsAboutToBeInserted, this, nullptr);
+            disconnect(sourceModel(), &QAbstractItemModel::rowsAboutToBeRemoved, this, nullptr);
+            disconnect(sourceModel(), &QAbstractItemModel::rowsInserted, this, nullptr);
+            disconnect(sourceModel(), &QAbstractItemModel::rowsRemoved, this, nullptr);
+        }
 
         ResourceCheckListModel* newModel;
         switch (type)
