@@ -1,7 +1,7 @@
 /*
  *  resource.cpp  -  generic class containing an alarm calendar resource
  *  Program:  kalarm
- *  Copyright © 2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2019-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,20 +24,20 @@
 #include "resourcedatamodelbase.h"
 #include "resourcemodel.h"
 #include "resourceselectdialog.h"
-#include "autoqpointer.h"
 #include "preferences.h"
+#include "lib/autoqpointer.h"
 #include "kalarm_debug.h"
 
 #include <KLocalizedString>
 
-Resources* Resources::mInstance{nullptr};
+Resources* Resources::mInstance {nullptr};
 
 // Copy of all ResourceType instances with valid ID, wrapped in the Resource
 // container which manages the instance.
 QHash<ResourceId, Resource> Resources::mResources;
 
-bool Resources::mCreated{false};
-bool Resources::mPopulated{false};
+bool Resources::mCreated {false};
+bool Resources::mPopulated {false};
 
 
 Resources* Resources::instance()
@@ -51,6 +51,13 @@ Resources::Resources()
 {
 }
 
+Resources::~Resources()
+{
+    qCDebug(KALARM_LOG) << "Resources::~Resources";
+    for (auto it = mResources.begin();  it != mResources.end();  ++it)
+        it.value().close();
+}
+
 Resource Resources::resource(ResourceId id)
 {
     return mResources.value(id, Resource::null());
@@ -238,11 +245,11 @@ void Resources::setStandard(Resource& resource, CalEvent::Types types)
 }
 
 /******************************************************************************
-* Get the collection to use for storing an alarm.
-* Optionally, the standard collection for the alarm type is returned. If more
-* than one collection is a candidate, the user is prompted.
+* Find the resource to be used to store an event of a given type.
+* This will be the standard resource for the type, but if this is not valid,
+* the user will be prompted to select a resource.
 */
-Resource Resources::destination(ResourceListModel* model, CalEvent::Type type, QWidget* promptParent, bool noPrompt, bool* cancelled)
+Resource Resources::destination(CalEvent::Type type, QWidget* promptParent, bool noPrompt, bool* cancelled)
 {
     if (cancelled)
         *cancelled = false;
@@ -257,6 +264,7 @@ Resource Resources::destination(ResourceListModel* model, CalEvent::Type type, Q
         return standard;
 
     // Prompt for which collection to use
+    ResourceListModel* model = DataModel::createResourceListModel(promptParent);
     model->setFilterWritable(true);
     model->setFilterEnabled(true);
     model->setEventTypeFilter(type);
@@ -386,6 +394,27 @@ void Resources::notifyResourcePopulated(const ResourceType* res)
     checkResourcesPopulated();
 }
 
+/******************************************************************************
+* Called to notify that migration/creation of resources has completed.
+*/
+void Resources::notifyResourcesMigrated()
+{
+    Q_EMIT instance()->migrationCompleted();
+}
+
+/******************************************************************************
+* Called to notify that a resource is about to be removed.
+*/
+void Resources::notifyResourceToBeRemoved(ResourceType* res)
+{
+    if (res)
+    {
+        Resource r = resource(res->id());
+        if (r.isValid())
+            Q_EMIT instance()->resourceToBeRemoved(r);
+    }
+}
+
 /******************************************************************************
 * Called by a resource to notify that its settings have changed.
 * Emits the settingsChanged() signal.
@@ -441,7 +470,7 @@ void Resources::notifySettingsChanged(ResourceType* res, ResourceType::Changes c
 
     if ((change & ResourceType::ReadOnly)  &&  res->readOnly())
     {
-        qCDebug(KALARM_LOG) << "Resources::notifySettingsChanged:" << res->id() << "ReadOnly";
+        qCDebug(KALARM_LOG) << "Resources::notifySettingsChanged:" << res->displayId() << "ReadOnly";
         // A read-only resource can't be the default for any alarm type
         const CalEvent::Types std = standardTypes(r, false);
         if (std != CalEvent::EMPTY)
