@@ -1,7 +1,7 @@
 /*
  *  resources.h  -  container for all ResourceType instances
  *  Program:  kalarm
- *  Copyright © 2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2019-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #ifndef RESOURCES_H
 #define RESOURCES_H
 
+#include "datamodel.h"
 #include "resource.h"
 #include "resourcemodel.h"
 
@@ -39,7 +40,7 @@ public:
     /** Creates the unique Resources instance. */
     static Resources* instance();
 
-    ~Resources() {}
+    ~Resources();
     Resources(const Resources&) = delete;
     Resources& operator=(const Resources&) const = delete;
 
@@ -121,7 +122,6 @@ public:
      *  @param cancelled    If non-null: set to true if the user cancelled the
      *                      prompt dialogue; set to false if any other error
      */
-    template <class DataModel>
     static Resource destination(CalEvent::Type type, QWidget* promptParent = nullptr, bool noPrompt = false, bool* cancelled = nullptr);
 
     /** Return whether all configured resources have been created. */
@@ -151,6 +151,12 @@ public:
     /** Called by a resource to notify that loading of events has successfully completed. */
     static void notifyResourcePopulated(const ResourceType*);
 
+    /** Called to notify that migration/creation of resources has completed. */
+    static void notifyResourcesMigrated();
+
+    /** Called to notify that a resource is about to be removed. */
+    static void notifyResourceToBeRemoved(ResourceType*);
+
     /** Called by a resource to notify that its settings have changed.
      *  This will cause the settingsChanged() signal to be emitted.
      */
@@ -173,7 +179,9 @@ public:
     /** Called by a resource to notify that it has added events. */
     static void notifyEventsAdded(ResourceType*, const QList<KAEvent>&);
 
-    /** Called by a resource to notify that it has changed an event. */
+    /** Called by a resource to notify that it has changed an event.
+     *  The event's UID must be unchanged.
+     */
     static void notifyEventUpdated(ResourceType*, const KAEvent& event);
 
     /** Called by a resource to notify that it is about to delete events. */
@@ -184,18 +192,27 @@ Q_SIGNALS:
     void settingsChanged(Resource&, ResourceType::Changes);
 
     /** Emitted when all configured resource have been created (but not
-     *  necessarily populated). */
+     *  necessarily populated). Note that after this, resource migration and
+     *  the creation of default resources is performed and notified by the
+     *  signal migrationCompleted().
+     */
     void resourcesCreated();
 
     /** Emitted when all configured resources have been loaded for the first time. */
     void resourcesPopulated();
 
+    /** Signal emitted when resource migration/creation at startup has completed. */
+    void migrationCompleted();
+
     /** Emitted when a new resource has been created. */
     void resourceAdded(Resource&);
 
     /** Emitted when a resource's events have been successfully loaded. */
     void resourcePopulated(Resource&);
 
+    /** Emitted when a resource's config and settings are about to be removed. */
+    void resourceToBeRemoved(Resource&);
+
     /** Emitted when a resource's config and settings have been removed. */
     void resourceRemoved(ResourceId);
 
@@ -212,6 +229,7 @@ Q_SIGNALS:
 
     /** Emitted when an event has been updated in a resource.
      *  Events are only notified whose alarm type is enabled.
+     *  The event's UID is unchanged.
      */
     void eventUpdated(Resource&, const KAEvent&);
 
@@ -222,7 +240,6 @@ Q_SIGNALS:
 
 private:
     Resources();
-    static Resource destination(ResourceListModel* model, CalEvent::Type type, QWidget* promptParent, bool noPrompt, bool* cancelled);
 
     /** Add a new ResourceType instance, with a Resource owner.
      *  Once the resource has completed its initialisation, call
@@ -275,13 +292,6 @@ QVector<Resource> Resources::allResources(CalEvent::Type type)
     return result;
 }
 
-template <class DataModel>
-Resource Resources::destination(CalEvent::Type type, QWidget* promptParent, bool noPrompt, bool* cancelled)
-{
-    ResourceListModel* model = ResourceListModel::create<DataModel>(promptParent);
-    return destination(model, type, promptParent, noPrompt, cancelled);
-}
-
 #endif // RESOURCES_H
 
 // vim: et sw=4:
