@@ -1,7 +1,7 @@
 /*
  *  resourcetype.h  -  base class for an alarm calendar resource type
  *  Program:  kalarm
- *  Copyright © 2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2019-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,8 +21,8 @@
 #ifndef RESOURCETYPE_H
 #define RESOURCETYPE_H
 
-#include <kalarmcal/kacalendar.h>
-#include <kalarmcal/kaevent.h>
+#include <KAlarmCal/KACalendar>
+#include <KAlarmCal/KAEvent>
 
 #include <QObject>
 #include <QSharedPointer>
@@ -79,12 +79,26 @@ public:
 
     virtual ~ResourceType() = 0;
 
-    /** Return whether the resource has a valid configuration. */
+    /** Return whether the resource has a valid configuration.
+     *  Note that the resource may be unusable even if it has a valid
+     *  configuration: see failed().
+     */
     virtual bool isValid() const = 0;
 
+    /** Return whether the resource has a fatal error.
+     *  Note that failed() will return true if the configuration is invalid
+     *  (i.e. isValid() returns false). It will also return true if some other
+     *  error prevents the resource being used, e.g. if the calendar file
+     *  cannot be created.
+     */
+    bool failed() const;
+
     /** Return the resource's unique ID. */
     ResourceId id() const    { return mId; }
 
+    /** Return the resource's unique ID, as shown to the user. */
+    virtual ResourceId displayId() const;
+
     /** Return the type of storage used by the resource. */
     virtual StorageType storageType() const = 0;
 
@@ -95,6 +109,11 @@ public:
      */
     virtual QString storageTypeString(bool description) const = 0;
 
+    /** Return the type description of a resource (file, remote file, etc.)
+     *  for display purposes. This is equivalent to storageTypeString(true).
+     */
+    static QString storageTypeString(StorageType);
+
     /** Return the location(s) of the resource (URL, file path, etc.) */
     virtual QUrl location() const = 0;
 
@@ -172,11 +191,11 @@ public:
 #endif
 
     /** Return whether the user has chosen not to update the resource's
-     *  calendar storage formst. */
+     *  calendar storage format. */
     virtual bool keepFormat() const = 0;
 
     /** Set or clear whether the user has chosen not to update the resource's
-     *  calendar storage formst. */
+     *  calendar storage format. */
     virtual void setKeepFormat(bool keep) = 0;
 
     /** Return the background colour used to display alarms belonging to
@@ -250,15 +269,25 @@ public:
      */
     virtual void configSetStandard(CalEvent::Types types) = 0;
 
+    /** Return whether the resource is in the current KAlarm format.
+     *  @see compatibility(), compatibilityVersion()
+     */
+    bool isCompatible() const;
+
     /** Return whether the resource is in a different format from the
      *  current KAlarm format, in which case it cannot be written to.
      *  Note that isWritable() takes account of incompatible format
      *  as well as read-only and enabled statuses.
      */
-    virtual KACalendar::Compat compatibility() const = 0;
+    KACalendar::Compat compatibility() const;
 
-    /** Return whether the resource is in the current KAlarm format. */
-    bool isCompatible() const;
+    /** Return whether the resource is in a different format from the
+     *  current KAlarm format, in which case it cannot be written to.
+     *  Note that isWritable() takes account of incompatible format
+     *  as well as read-only and enabled statuses.
+     *  @param versionString  Receives calendar's KAlarm version as a string.
+     */
+    virtual KACalendar::Compat compatibilityVersion(QString& versionString) const = 0;
 
     /** Edit the resource's configuration. */
     virtual void editResource(QWidget* dialogParent) = 0;
@@ -287,10 +316,8 @@ public:
      */
     virtual bool load(bool readThroughCache = true) = 0;
 
-#if 0
     /** Reload the resource. Any cached data is first discarded. */
     virtual bool reload() = 0;
-#endif
 
     /** Return whether the resource has fully loaded.
      *  Once loading completes after the resource has initialised, this should
@@ -304,14 +331,21 @@ public:
      *  if @p writeThroughCache is true, will then be uploaded from the resource file).
      *  @param writeThroughCache  If the resource is cached, update the file
      *                            after writing to the cache.
+     *  @param force              Save even if no changes have been made since last
+     *                            loaded or saved.
      *  @return true if saving succeeded or has been initiated.
      *          false if it failed.
      */
-    virtual bool save(bool writeThroughCache = true) = 0;
+    virtual bool save(bool writeThroughCache = true, bool force = false) = 0;
 
     /** Return whether the resource is waiting for a save() to complete. */
     virtual bool isSaving() const   { return false; }
 
+    /** Close the resource. This saves any unsaved data.
+     *  Saving is not performed if the resource is disabled.
+     */
+    virtual void close() {}
+
     /** Return all events belonging to this resource, for enabled alarm types. */
     QList<KAEvent> events() const;
 
@@ -384,9 +418,16 @@ protected:
     void setLoadedEvents(QHash<QString, KAEvent>& newEvents);
 
     /** To be called when events have been created or updated, to amend them in
-     * the resource's list.
+     *  the resource's list.
+     *  @param notify  Whether to notify added and updated events; if false,
+     *                 notifyUpdatedEvents() must be called afterwards.
      */
-    void setUpdatedEvents(const QList<KAEvent>& events);
+    void setUpdatedEvents(const QList<KAEvent>& events, bool notify = true);
+
+    /** Notify added and updated events, if setUpdatedEvents() was called with
+     *  notify = false.
+     */
+    void notifyUpdatedEvents();
 
     /** To be called when events have been deleted, to delete them from the resource's list. */
     void setDeletedEvents(const QList<KAEvent>& events);
@@ -394,7 +435,13 @@ protected:
     /** To be called when the loaded status of the resource has changed. */
     void setLoaded(bool loaded) const;
 
-    QString storageTypeStr(bool description, bool file, bool local) const;
+    /** To be called if the resource has encountered a fatal error.
+     *  A fatal error is one that can never be recovered from.
+     */
+    void setFailed();
+
+    static QString storageTypeStr(bool description, bool file, bool local);
+
     template <class T> static T* resource(Resource&);
     template <class T> static const T* resource(const Resource&);
 
@@ -402,10 +449,13 @@ private:
     static ResourceType* data(Resource&);
     static const ResourceType* data(const Resource&);
 
-    QHash<QString, KAEvent> mEvents;    // all events (of ALL types) in the resource, indexed by ID
-    ResourceId   mId{-1};               // resource's ID, which can't be changed
-    mutable bool mLoaded{false};        // the resource has finished loading
-    bool         mBeingDeleted{false};  // the resource is currently being deleted
+    QHash<QString, KAEvent> mEvents;     // all events (of ALL types) in the resource, indexed by ID
+    QList<KAEvent> mEventsAdded;         // events added to mEvents but not yet notified
+    QList<KAEvent> mEventsUpdated;       // events updated in mEvents but not yet notified
+    ResourceId   mId {-1};               // resource's ID, which can't be changed
+    bool         mFailed {false};        // the resource has a fatal error
+    mutable bool mLoaded {false};        // the resource has finished loading
+    bool         mBeingDeleted {false};  // the resource is currently being deleted
 };
 
 
